@@ -16,6 +16,7 @@ import rich_click as click
 from dda._version import __version__
 from dda.cli.base import dynamic_group
 from dda.config.constants import AppEnvVars, ConfigEnvVars
+from dda.utils.terminal import terminal_size
 
 if TYPE_CHECKING:
     from dda.config.file import ConfigFile
@@ -56,7 +57,12 @@ def set_default_config(
 
 
 @dynamic_group(
-    context_settings={"help_option_names": ["-h", "--help"], "max_content_width": 120, "show_default": True},
+    context_settings={
+        "help_option_names": ["-h", "--help"],
+        "terminal_width": terminal_size().columns,
+        "max_content_width": terminal_size().columns,
+        "show_default": True,
+    },
     invoke_without_command=True,
     allow_external_plugins=True,
     search_path_finder=search_path_finder,
@@ -175,17 +181,9 @@ def dda(
     app = Application(terminator=ctx.exit, config_file=config, enable_color=color, interactive=interactive)
 
     # Persist app data for sub-commands
-    ctx.obj = app
+    ctx.obj = ctx.with_resource(app)
 
     # Telemetry submission
-    if not app.telemetry.consent_recorded() and app.console.is_interactive:
-        if app.confirm(
-            "Would you like to enable telemetry to help improve the tool (only works for Datadog employees)"
-        ):
-            app.telemetry.consent()
-        else:
-            app.telemetry.dissent()
-
     app.telemetry.watch()
 
     if not ctx.invoked_subcommand:
