@@ -140,9 +140,19 @@ class DynamicContext(click.RichContext):
             metadata = {
                 "cli.command": join_command_args(sys.argv[1:]),
                 "cli.exit_code": str(exit_code),
-                "git.author.name": app.config.git.user.name,
-                "git.author.email": app.config.git.user.email,
+                "author.name": app.telemetry.user_name,
+                "author.email": app.telemetry.user_email,
+                # TODO: Remove this once the new keys are fully rolled out
+                "git.author.name": app.telemetry.user_name,
+                "git.author.email": app.telemetry.user_email,
             }
+            if os.environ.get("PRE_COMMIT") == "1":
+                metadata["exec.source"] = "pre-commit"
+            elif os.environ.get("PYCLI_MCP_TOOL_NAME"):
+                metadata["exec.source"] = "mcp"
+            else:
+                metadata["exec.source"] = "human"
+
             if last_error := app.last_error.strip():
                 # Payload limit is 5MB so we truncate the error message to a little bit less than that
                 message_max_length = int(1024 * 1024 * 4.5)
@@ -492,6 +502,16 @@ def ensure_features_installed(
         app.tools.uv.wait(command, message="Synchronizing dependencies", cwd=str(temp_dir), env=env_vars)
 
 
+def get_raw_args(ctx: click.Context) -> list[str]:
+    level = len(ctx.command_path.split())
+    return _get_argv()[level:]
+
+
+def _get_argv() -> list[str]:
+    # This is used for test assertions only
+    return sys.argv
+
+
 def _get_root_ctx(ctx: click.Context) -> DynamicContext:
     while ctx.parent is not None:
         ctx = ctx.parent
