@@ -7,7 +7,7 @@ from typing import TYPE_CHECKING
 
 import click
 
-from dda.cli.base import dynamic_command
+from dda.cli.base import dynamic_command, pass_app
 from dda.cli.env.dev.utils import option_env_type
 
 if TYPE_CHECKING:
@@ -17,7 +17,7 @@ if TYPE_CHECKING:
 @dynamic_command(short_help="Access a developer environment through a graphical interface")
 @option_env_type()
 @click.option("--id", "instance", default="default", help="Unique identifier for the environment")
-@click.pass_obj
+@pass_app
 def cmd(app: Application, *, env_type: str, instance: str) -> None:
     """
     Access a developer environment through a graphical interface.
