@@ -3,12 +3,15 @@
 # SPDX-License-Identifier: MIT
 from __future__ import annotations
 
+import os
+import sys
 from functools import cached_property
 from typing import TYPE_CHECKING, Annotated, Any, Literal, NoReturn
 
 import msgspec
 
 from dda.env.dev.interface import DeveloperEnvironmentConfig, DeveloperEnvironmentInterface
+from dda.utils.git.constants import GitEnvVars
 
 if TYPE_CHECKING:
     from dda.env.models import EnvironmentStatus
@@ -87,12 +90,6 @@ class LinuxContainer(DeveloperEnvironmentInterface[LinuxContainerConfig]):
             self.docker.wait(["start", self.container_name], message=f"Starting container: {self.container_name}")
         else:
             from dda.config.constants import AppEnvVars
-            from dda.utils._git import (
-                GIT_AUTHOR_EMAIL_ENV_VAR,
-                GIT_AUTHOR_NAME_ENV_VAR,
-                get_git_author_email,
-                get_git_author_name,
-            )
             from dda.utils.process import EnvVars
             from dda.utils.retry import wait_for
 
@@ -112,17 +109,29 @@ class LinuxContainer(DeveloperEnvironmentInterface[LinuxContainerConfig]):
                 self.container_name,
                 "-p",
                 f"{self.ssh_port}:22",
+                "-p",
+                f"{self.mcp_port}:9000",
                 "-v",
                 "/var/run/docker.sock:/var/run/docker.sock",
+            ]
+            if sys.platform != "win32":
+                command.extend((
+                    "-e",
+                    f"HOST_UID={os.getuid()}",
+                    "-e",
+                    f"HOST_GID={os.getgid()}",
+                ))
+
+            command.extend((
                 "-e",
                 "DD_SHELL",
                 "-e",
                 AppEnvVars.TELEMETRY_API_KEY,
                 "-e",
-                GIT_AUTHOR_NAME_ENV_VAR,
+                GitEnvVars.AUTHOR_NAME,
                 "-e",
-                GIT_AUTHOR_EMAIL_ENV_VAR,
-            ]
+                GitEnvVars.AUTHOR_EMAIL,
+            ))
             if self.config.arch is not None:
                 command.extend(("--platform", f"linux/{self.config.arch}"))
 
@@ -151,12 +160,10 @@ class LinuxContainer(DeveloperEnvironmentInterface[LinuxContainerConfig]):
             env["DD_SHELL"] = self.config.shell
             if self.app.telemetry.api_key is not None:
                 env[AppEnvVars.TELEMETRY_API_KEY] = self.app.telemetry.api_key
-
-            if git_user := (self.app.config.git.user.name or get_git_author_name()):
-                env[GIT_AUTHOR_NAME_ENV_VAR] = git_user
-
-            if git_email := (self.app.config.git.user.email or get_git_author_email()):
-                env[GIT_AUTHOR_EMAIL_ENV_VAR] = git_email
+            if self.app.config.tools.git.author.name:
+                env[GitEnvVars.AUTHOR_NAME] = self.app.config.tools.git.author.name
+            if self.app.config.tools.git.author.email:
+                env[GitEnvVars.AUTHOR_EMAIL] = self.app.config.tools.git.author.email
 
             self.docker.wait(
                 command,
@@ -235,7 +242,22 @@ class LinuxContainer(DeveloperEnvironmentInterface[LinuxContainerConfig]):
             self.app.abort(f"Unsupported editor: {editor.name}")
 
         self.ensure_ssh_config()
-        editor.open_via_ssh(server=self.hostname, port=self.ssh_port, path=self.repo_path(repo))
+        repo_path = self.repo_path(repo)
+
+        # TODO: Currently, we do not support aggregating local commands from multiple repositories as a single tool
+        #       so we assume for the purposes of MCP that only one repository is open at a time. We should extend
+        #       the MCP server to support multiple repositories. Documentation for extending the MCP server is here:
+        #       https://ofek.dev/pycli-mcp/api/
+        self.app.subprocess.wait(
+            self.construct_command(["dda", "self", "mcp-server", "stop"], cwd=repo_path),
+            message="Stopping MCP server",
+        )
+        self.app.subprocess.wait(
+            self.construct_command(["dda", "self", "mcp-server", "start"], cwd=repo_path),
+            message="Starting MCP server",
+        )
+
+        editor.open_via_ssh(server=self.hostname, port=self.ssh_port, path=repo_path)
 
     def run_command(self, command: list[str], *, repo: str | None = None) -> None:
         self.ensure_ssh_config()
@@ -285,9 +307,15 @@ class LinuxContainer(DeveloperEnvironmentInterface[LinuxContainerConfig]):
 
     @cached_property
     def ssh_port(self) -> int:
-        from dda.utils.ssh import derive_dynamic_ssh_port
+        from dda.utils.network.protocols import derive_dynamic_port
 
-        return derive_dynamic_ssh_port(self.container_name)
+        return derive_dynamic_port(f"{self.container_name}-ssh")
+
+    @cached_property
+    def mcp_port(self) -> int:
+        from dda.utils.network.protocols import derive_dynamic_port
+
+        return derive_dynamic_port(f"{self.container_name}-mcp")
 
     @cached_property
     def home_dir(self) -> str:
@@ -314,6 +342,8 @@ class LinuxContainer(DeveloperEnvironmentInterface[LinuxContainerConfig]):
             Mount(type="volume", path="/go/pkg/mod", source=self.get_volume_name("go_mod_cache")),
             # `pip cache dir`
             Mount(type="volume", path="/root/.cache/pip", source=self.get_volume_name("pip_cache")),
+            # `uv cache dir`
+            Mount(type="volume", path="/root/.cache/uv", source=self.get_volume_name("uv_cache")),
             # Rust
             Mount(type="volume", path="/root/.cargo/registry", source=self.get_volume_name("cargo_registry")),
             Mount(type="volume", path="/root/.cargo/git", source=self.get_volume_name("cargo_git")),
