@@ -13,3 +13,5 @@ class DaemonEnvVars:
     COMMAND_PID = "DDA_TELEMETRY_COMMAND_PID"
     WRITE_DIR = "DDA_TELEMETRY_WRITE_DIR"
     LOG_FILE = "DDA_TELEMETRY_LOG_FILE"
+    LOG_LEVEL = "DDA_TELEMETRY_LOG_LEVEL"
+    ERROR_FILE = "DDA_TELEMETRY_ERROR_FILE"
