@@ -27,7 +27,7 @@ class TelemetryManager:
     @property
     def enabled(self) -> bool:
         """
-        Whether the user has consented to telemetry.
+        Whether the user has not dissented to telemetry.
         """
         return self.__enabled
 
@@ -48,20 +48,21 @@ class TelemetryManager:
             self.__start_daemon()
 
     def consent(self) -> None:
-        self.__consent_file.parent.ensure_dir()
-        self.__consent_file.write_text("1", encoding="utf-8")
+        if self.__dissent_file.is_file():
+            self.__dissent_file.unlink()
 
     def dissent(self) -> None:
-        self.__consent_file.parent.ensure_dir()
-        self.__consent_file.write_text("0", encoding="utf-8")
-
-    def consent_recorded(self) -> bool:
-        return self.__consent_file.is_file()
+        if not self.__dissent_file.is_file():
+            self.__dissent_file.parent.ensure_dir()
+            self.__dissent_file.touch()
 
     def clear_log(self) -> None:
         if self.log_file.is_file():
             self.log_file.unlink()
 
+    def error_state(self) -> bool:
+        return self.__error_file.is_file()
+
     @cached_property
     def log_file(self) -> Path:
         return self.__storage_dir / "daemon.log"
@@ -85,12 +86,32 @@ class TelemetryManager:
         return api_key
 
     @cached_property
-    def __enabled(self) -> bool:
-        return self.__consent_file.read_text(encoding="utf-8") == "1" if self.consent_recorded() else False
+    def user_name(self) -> str:
+        return (
+            self.__app.config.user.name
+            if self.__app.config.user.name != "auto"
+            else self.__app.config.tools.git.author.name
+        )
 
     @cached_property
-    def __consent_file(self) -> Path:
-        return self.__storage_dir / "consent.txt"
+    def user_email(self) -> str:
+        return (
+            self.__app.config.user.email
+            if self.__app.config.user.email != "auto"
+            else self.__app.config.tools.git.author.email
+        )
+
+    @cached_property
+    def __enabled(self) -> bool:
+        return not self.__dissent_file.is_file()
+
+    @cached_property
+    def __dissent_file(self) -> Path:
+        return self.__storage_dir / "dissent"
+
+    @cached_property
+    def __error_file(self) -> Path:
+        return self.__storage_dir / "daemon.error"
 
     @cached_property
     def __storage_dir(self) -> Path:
@@ -115,6 +136,7 @@ class TelemetryManager:
             DaemonEnvVars.COMMAND_PID: str(os.getpid()),
             DaemonEnvVars.WRITE_DIR: str(self.__write_dir),
             DaemonEnvVars.LOG_FILE: str(self.log_file),
+            DaemonEnvVars.ERROR_FILE: str(self.__error_file),
         })
         self.__app.subprocess.spawn_daemon([sys.executable, "-m", "dda.telemetry.daemon"], env=env_vars)
         self.__started = True
