@@ -8,7 +8,9 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from dda.cli.application import Application
+    from dda.tools.bazel import Bazel
     from dda.tools.docker import Docker
+    from dda.tools.git import Git
     from dda.tools.go import Go
     from dda.tools.uv import UV
 
@@ -21,6 +23,12 @@ class Tools:
     def __init__(self, app: Application) -> None:
         self.__app = app
 
+    @cached_property
+    def bazel(self) -> Bazel:
+        from dda.tools.bazel import Bazel
+
+        return Bazel(self.__app)
+
     @cached_property
     def docker(self) -> Docker:
         from dda.tools.docker import Docker
@@ -38,3 +46,9 @@ class Tools:
         from dda.tools.uv import UV
 
         return UV(self.__app)
+
+    @cached_property
+    def git(self) -> Git:
+        from dda.tools.git import Git
+
+        return Git(self.__app)
