@@ -7,4 +7,8 @@ import os
 
 
 def running_in_ci() -> bool:
+    """
+    Returns:
+        Whether the current process is running in a CI environment.
+    """
     return any(os.environ.get(env_var) in {"true", "1"} for env_var in ("CI", "GITHUB_ACTIONS"))
