@@ -251,6 +251,21 @@ class SubprocessRunner:
         check: bool,
         capture: bool,
     ) -> tuple[int, str]:
+        from dda.utils.ci import running_in_ci
+
+        if self.__app.force_interactive or running_in_ci():
+            import subprocess
+
+            kwargs: dict[str, Any] = {"env": env, "cwd": cwd}
+            if capture:
+                kwargs["encoding"] = encoding
+                kwargs["stdout"] = subprocess.PIPE
+                kwargs["stderr"] = subprocess.STDOUT
+
+            cmd, kwargs = self.__sanitize_arguments(command, **kwargs)
+            process = subprocess.run(cmd, **kwargs)  # noqa: PLW1510
+            return process.returncode, process.stdout if capture else ""
+
         import tempfile
         import threading
 
@@ -300,7 +315,7 @@ class SubprocessRunner:
         def replace_current_process(self, command: list[str]) -> NoReturn:
             self.exit_with(command)
 
-        def spawn_daemon(self, command: list[str] | str, **kwargs: Any) -> None:
+        def spawn_daemon(self, command: list[str] | str, **kwargs: Any) -> int:
             """
             Spawn a daemon process that is detached from the current process.
 
@@ -312,22 +327,21 @@ class SubprocessRunner:
             """
             import subprocess
 
-            kwargs["creationflags"] = (
-                subprocess.CREATE_NEW_PROCESS_GROUP | subprocess.DETACHED_PROCESS | subprocess.CREATE_NO_WINDOW
-            )
+            kwargs["creationflags"] = subprocess.CREATE_NEW_PROCESS_GROUP | subprocess.CREATE_NO_WINDOW
             kwargs["stdin"] = subprocess.DEVNULL
             kwargs["stdout"] = subprocess.DEVNULL
             kwargs["stderr"] = subprocess.DEVNULL
             kwargs["close_fds"] = True
             command, kwargs = self.__sanitize_arguments(command, **kwargs)
-            subprocess.Popen(command, **kwargs)
+            process = subprocess.Popen(command, **kwargs)
+            return process.pid
 
     else:
 
         def replace_current_process(self, command: list[str]) -> NoReturn:  # noqa: PLR6301
             os.execvp(command[0], command)  # noqa: S606
 
-        def spawn_daemon(self, command: list[str] | str, **kwargs: Any) -> None:
+        def spawn_daemon(self, command: list[str] | str, **kwargs: Any) -> int:
             """
             Spawn a daemon process that is detached from the current process.
 
@@ -345,7 +359,8 @@ class SubprocessRunner:
             kwargs["stderr"] = subprocess.DEVNULL
             kwargs["close_fds"] = True
             command, kwargs = self.__sanitize_arguments(command, **kwargs)
-            subprocess.Popen(command, **kwargs)
+            process = subprocess.Popen(command, **kwargs)
+            return process.pid
 
     @staticmethod
     def __sanitize_arguments(command: list[str] | str, **kwargs: Any) -> tuple[list[str] | str, dict[str, Any]]:
