@@ -7,6 +7,7 @@ import os
 import pathlib
 import shutil
 import sys
+import time
 from typing import TYPE_CHECKING
 
 import pytest
@@ -18,13 +19,16 @@ from dda.config.constants import AppEnvVars, ConfigEnvVars
 from dda.config.file import ConfigFile
 from dda.utils.ci import running_in_ci
 from dda.utils.fs import Path, temp_directory
-from dda.utils.platform import PLATFORM_ID
+from dda.utils.git.constants import GitEnvVars
+from dda.utils.platform import PLATFORM_ID, which
 from dda.utils.process import EnvVars
 
 if TYPE_CHECKING:
     import pathlib
     from collections.abc import Generator
 
+    from dda.config.model.tools import GitAuthorConfig
+
 
 class CliRunner(__CliRunner):
     def __init__(self, command):
@@ -56,21 +60,30 @@ def temp_dir(tmp_path: pathlib.Path) -> Path:
 
 
 @pytest.fixture(scope="session", autouse=True)
-def isolation() -> Generator[Path, None, None]:
+def isolation(default_git_author: GitAuthorConfig) -> Generator[Path, None, None]:
     with temp_directory() as d:
         data_dir = d / "data"
         data_dir.mkdir()
         cache_dir = d / "cache"
         cache_dir.mkdir()
 
+        # Disable telemetry
+        dissent_file = cache_dir / "telemetry" / "dissent"
+        dissent_file.parent.ensure_dir()
+        dissent_file.touch()
+
+        # Disable update checker
+        last_update_check_file = cache_dir / "last_update_check"
+        last_update_check_file.write_text(str(time.time()), encoding="utf-8")
+
         default_env_vars = {
             ConfigEnvVars.DATA: str(data_dir),
             ConfigEnvVars.CACHE: str(cache_dir),
             AppEnvVars.NO_COLOR: "1",
             "PYAPP": "1",
             "DDA_SELF_TESTING": "true",
-            "GIT_AUTHOR_NAME": "Foo Bar",
-            "GIT_AUTHOR_EMAIL": "foo@bar.baz",
+            GitEnvVars.AUTHOR_NAME: default_git_author.name,
+            GitEnvVars.AUTHOR_EMAIL: default_git_author.email,
             "COLUMNS": "80",
             "LINES": "24",
         }
@@ -104,6 +117,16 @@ def private_storage(config_file: ConfigFile) -> Generator[None, None, None]:
     cache_dir.mkdir()
     data_dir = config_file.path.parent / "data"
     data_dir.mkdir()
+
+    # Disable telemetry
+    dissent_file = cache_dir / "telemetry" / "dissent"
+    dissent_file.parent.ensure_dir()
+    dissent_file.touch()
+
+    # Disable update checker
+    last_update_check_file = cache_dir / "last_update_check"
+    last_update_check_file.write_text(str(time.time()), encoding="utf-8")
+
     config_file.data["storage"] = {"cache": str(cache_dir), "data": str(data_dir)}
     config_file.save()
     with EnvVars({ConfigEnvVars.CACHE: str(cache_dir), ConfigEnvVars.DATA: str(data_dir)}):
@@ -125,11 +148,23 @@ def default_cache_dir() -> Path:
     return Path(user_cache_dir("dda", appauthor=False))
 
 
+@pytest.fixture(scope="session")
+def default_git_author() -> GitAuthorConfig:
+    from dda.config.model.tools import GitAuthorConfig
+
+    return GitAuthorConfig(name="Foo Bar", email="foo@bar.baz")
+
+
 @pytest.fixture(scope="session")
 def uv_on_path() -> Path:
     return Path(shutil.which("uv"))
 
 
+@pytest.fixture(scope="session")
+def bazel_on_path() -> Path:
+    return Path(which("bazel"))
+
+
 def pytest_runtest_setup(item):
     for marker in item.iter_markers():
         if marker.name == "requires_ci" and not running_in_ci():  # no cov
