@@ -4,6 +4,7 @@
 from __future__ import annotations
 
 import json
+import os
 import subprocess
 import sys
 from subprocess import CompletedProcess
@@ -14,6 +15,7 @@ import pytest
 from dda.config.constants import AppEnvVars
 from dda.env.dev.types.linux_container import LinuxContainer
 from dda.utils.fs import Path
+from dda.utils.git.constants import GitEnvVars
 
 pytestmark = [pytest.mark.usefixtures("private_storage")]
 
@@ -26,6 +28,11 @@ def updated_config(config_file):
         config_file.save()
 
 
+@pytest.fixture(scope="module")
+def host_user_args():
+    return [] if sys.platform == "win32" else ["-e", f"HOST_UID={os.getuid()}", "-e", f"HOST_GID={os.getgid()}"]
+
+
 def get_starship_mount(shared_dir: Path) -> list[str]:
     starship_config_file = Path.home() / ".config" / "starship.toml"
     if not starship_config_file.exists():
@@ -43,6 +50,8 @@ def get_cache_volumes() -> list[str]:
         "--mount",
         "type=volume,src=dda-env-dev-linux-container-pip_cache,dst=/root/.cache/pip",
         "--mount",
+        "type=volume,src=dda-env-dev-linux-container-uv_cache,dst=/root/.cache/uv",
+        "--mount",
         "type=volume,src=dda-env-dev-linux-container-cargo_registry,dst=/root/.cargo/registry",
         "--mount",
         "type=volume,src=dda-env-dev-linux-container-cargo_git,dst=/root/.cargo/git",
@@ -141,7 +150,7 @@ class TestStart:
             """
         )
 
-    def test_default(self, dda, helpers, mocker, temp_dir):
+    def test_default(self, dda, helpers, mocker, temp_dir, host_user_args):
         repos_dir = temp_dir / "repos"
         repos_dir.ensure_dir()
         repo_dir = repos_dir / "datadog-agent"
@@ -196,17 +205,20 @@ class TestStart:
                         "--name",
                         "dda-linux-container-default",
                         "-p",
-                        "59730:22",
+                        "61938:22",
+                        "-p",
+                        "50069:9000",
                         "-v",
                         "/var/run/docker.sock:/var/run/docker.sock",
+                        *host_user_args,
                         "-e",
                         "DD_SHELL",
                         "-e",
                         AppEnvVars.TELEMETRY_API_KEY,
                         "-e",
-                        "GIT_AUTHOR_NAME",
+                        GitEnvVars.AUTHOR_NAME,
                         "-e",
-                        "GIT_AUTHOR_EMAIL",
+                        GitEnvVars.AUTHOR_EMAIL,
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
@@ -220,7 +232,7 @@ class TestStart:
             ),
         ]
 
-    def test_clone(self, dda, helpers, mocker, temp_dir):
+    def test_clone(self, dda, helpers, mocker, temp_dir, host_user_args):
         write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
         with helpers.hybrid_patch(
             "subprocess.run",
@@ -269,17 +281,20 @@ class TestStart:
                         "--name",
                         "dda-linux-container-default",
                         "-p",
-                        "59730:22",
+                        "61938:22",
+                        "-p",
+                        "50069:9000",
                         "-v",
                         "/var/run/docker.sock:/var/run/docker.sock",
+                        *host_user_args,
                         "-e",
                         "DD_SHELL",
                         "-e",
                         AppEnvVars.TELEMETRY_API_KEY,
                         "-e",
-                        "GIT_AUTHOR_NAME",
+                        GitEnvVars.AUTHOR_NAME,
                         "-e",
-                        "GIT_AUTHOR_EMAIL",
+                        GitEnvVars.AUTHOR_EMAIL,
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
@@ -297,7 +312,7 @@ class TestStart:
                         "-q",
                         "-t",
                         "-p",
-                        "59730",
+                        "61938",
                         "root@localhost",
                         "--",
                         "cd /root && git dd-clone datadog-agent",
@@ -307,7 +322,7 @@ class TestStart:
             ),
         ]
 
-    def test_no_pull(self, dda, helpers, mocker, temp_dir):
+    def test_no_pull(self, dda, helpers, mocker, temp_dir, host_user_args):
         repos_dir = temp_dir / "repos"
         repos_dir.ensure_dir()
         repo_dir = repos_dir / "datadog-agent"
@@ -356,15 +371,18 @@ class TestStart:
                         "--name",
                         "dda-linux-container-default",
                         "-p",
-                        "59730:22",
+                        "61938:22",
+                        "-p",
+                        "50069:9000",
                         "-v",
                         "/var/run/docker.sock:/var/run/docker.sock",
+                        *host_user_args,
                         "-e",
                         "DD_SHELL",
                         "-e",
                         AppEnvVars.TELEMETRY_API_KEY,
                         "-e",
-                        "GIT_AUTHOR_NAME",
+                        GitEnvVars.AUTHOR_NAME,
                         "-e",
                         "GIT_AUTHOR_EMAIL",
                         *starship_mount,
@@ -380,7 +398,7 @@ class TestStart:
             ),
         ]
 
-    def test_multiple(self, dda, helpers, mocker, temp_dir):
+    def test_multiple(self, dda, helpers, mocker, temp_dir, host_user_args):
         repos_dir = temp_dir / "repos"
         repos_dir.ensure_dir()
         repo1_dir = repos_dir / "datadog-agent"
@@ -437,17 +455,20 @@ class TestStart:
                         "--name",
                         "dda-linux-container-default",
                         "-p",
-                        "59730:22",
+                        "61938:22",
+                        "-p",
+                        "50069:9000",
                         "-v",
                         "/var/run/docker.sock:/var/run/docker.sock",
+                        *host_user_args,
                         "-e",
                         "DD_SHELL",
                         "-e",
                         AppEnvVars.TELEMETRY_API_KEY,
                         "-e",
-                        "GIT_AUTHOR_NAME",
+                        GitEnvVars.AUTHOR_NAME,
                         "-e",
-                        "GIT_AUTHOR_EMAIL",
+                        GitEnvVars.AUTHOR_EMAIL,
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
@@ -463,7 +484,7 @@ class TestStart:
             ),
         ]
 
-    def test_multiple_clones(self, dda, helpers, mocker, temp_dir):
+    def test_multiple_clones(self, dda, helpers, mocker, temp_dir, host_user_args):
         write_server_config = mocker.patch("dda.utils.ssh.write_server_config")
         with helpers.hybrid_patch(
             "subprocess.run",
@@ -513,17 +534,20 @@ class TestStart:
                         "--name",
                         "dda-linux-container-default",
                         "-p",
-                        "59730:22",
+                        "61938:22",
+                        "-p",
+                        "50069:9000",
                         "-v",
                         "/var/run/docker.sock:/var/run/docker.sock",
+                        *host_user_args,
                         "-e",
                         "DD_SHELL",
                         "-e",
                         AppEnvVars.TELEMETRY_API_KEY,
                         "-e",
-                        "GIT_AUTHOR_NAME",
+                        GitEnvVars.AUTHOR_NAME,
                         "-e",
-                        "GIT_AUTHOR_EMAIL",
+                        GitEnvVars.AUTHOR_EMAIL,
                         *starship_mount,
                         "-v",
                         f"{shared_dir / 'shell' / 'zsh' / '.zsh_history'}:/root/.shared/shell/zsh/.zsh_history",
@@ -541,7 +565,7 @@ class TestStart:
                         "-q",
                         "-t",
                         "-p",
-                        "59730",
+                        "61938",
                         "root@localhost",
                         "--",
                         "cd /root && git dd-clone datadog-agent tag",
@@ -557,7 +581,7 @@ class TestStart:
                         "-q",
                         "-t",
                         "-p",
-                        "59730",
+                        "61938",
                         "root@localhost",
                         "--",
                         "cd /root && git dd-clone integrations-core",
@@ -675,7 +699,7 @@ class TestShell:
                         "-q",
                         "-t",
                         "-p",
-                        "59730",
+                        "61938",
                         "root@localhost",
                         "--",
                         "cd /root/repos/datadog-agent && zsh -l -i",
@@ -723,7 +747,7 @@ class TestRun:
                 "-q",
                 "-t",
                 "-p",
-                "59730",
+                "61938",
                 "root@localhost",
                 "--",
                 "cd /root/repos/datadog-agent && echo foo",
@@ -751,21 +775,26 @@ class TestCode:
         with helpers.hybrid_patch(
             "subprocess.run",
             return_values={
-                # Stop command checks the status
+                # Code command checks the status
                 1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
             },
         ):
             result = dda("env", "dev", "code")
 
         assert result.exit_code == 0, result.output
-        assert not result.output
+        assert result.output == helpers.dedent(
+            """
+            Stopping MCP server
+            Starting MCP server
+            """
+        )
 
         assert_ssh_config_written(write_server_config, "localhost")
         run.assert_called_once_with(
             [
                 "code",
                 "--remote",
-                "ssh-remote+root@localhost:59730",
+                "ssh-remote+root@localhost:61938",
                 "/root/repos/datadog-agent",
             ],
         )
@@ -777,21 +806,26 @@ class TestCode:
         with helpers.hybrid_patch(
             "subprocess.run",
             return_values={
-                # Stop command checks the status
+                # Code command checks the status
                 1: CompletedProcess([], returncode=0, stdout=json.dumps([{"State": {"Status": "running"}}])),
             },
         ):
             result = dda("env", "dev", "code", "--editor", "cursor")
 
         assert result.exit_code == 0, result.output
-        assert not result.output
+        assert result.output == helpers.dedent(
+            """
+            Stopping MCP server
+            Starting MCP server
+            """
+        )
 
         assert_ssh_config_written(write_server_config, "localhost")
         run.assert_called_once_with(
             [
                 "cursor",
                 "--remote",
-                "ssh-remote+root@localhost:59730",
+                "ssh-remote+root@localhost:61938",
                 "/root/repos/datadog-agent",
             ],
         )
@@ -813,14 +847,19 @@ class TestCode:
             result = dda("env", "dev", "code")
 
         assert result.exit_code == 0, result.output
-        assert not result.output
+        assert result.output == helpers.dedent(
+            """
+            Stopping MCP server
+            Starting MCP server
+            """
+        )
 
         assert_ssh_config_written(write_server_config, "localhost")
         run.assert_called_once_with(
             [
                 "cursor",
                 "--remote",
-                "ssh-remote+root@localhost:59730",
+                "ssh-remote+root@localhost:61938",
                 "/root/repos/datadog-agent",
             ],
         )
