@@ -6,7 +6,7 @@ from __future__ import annotations
 import pytest
 
 from dda.utils.fs import Path
-from dda.utils.ssh import derive_dynamic_ssh_port, ssh_base_command, write_server_config
+from dda.utils.ssh import ssh_base_command, write_server_config
 
 
 @pytest.mark.parametrize("port", [pytest.param(22, id="int port"), pytest.param("22", id="str port")])
@@ -14,10 +14,6 @@ def test_ssh_base_command(port: int | str) -> None:
     assert ssh_base_command("host", port) == ["ssh", "-A", "-q", "-t", "-p", str(port), "host", "--"]
 
 
-def test_derive_dynamic_ssh_port() -> None:
-    assert 49152 <= derive_dynamic_ssh_port("key") <= 65535
-
-
 @pytest.mark.usefixtures("fs")
 def test_write_server_config() -> None:
     hostname = "localhost"
